# generated by datamodel-codegen:
#   filename:  exportpdf_parameters_v1.json

from __future__ import annotations

from typing import Literal, Optional

from pydantic import AnyUrl, BaseModel, ConfigDict, conint, constr


class ImageParams(BaseModel):
    model_config = ConfigDict(
        extra='allow',
        frozen=True,
    )
    draw_annotations: Optional[bool] = True
    """
    Specify whether to include PDF annotations in the output image file(s).
    """
    image_format: Optional[Literal['jpeg', 'png', 'tiff']] = ['jpeg']
    """
    The format of the image to generate.
    """
    max_dimension: Optional[conint(ge=32, le=8192)] = None
    """
    Max dimension of any image in pixels. This can range from 32 to 8192.
    """
    pages: Optional[
        constr(pattern=r'^([1-9 ]+[0-9 ]*-?[0-9 ]*)(,[1-9 ]+[0-9 ]*-?[0-9 ]*)*$')
    ] = '1-'
    """
    Page range to be included. Page numbers are 1-based, comma seperated, and can include spaces (0x20, ignored) and a dash ('-', 0x2D) -- used to denote a range of pages.
    """
    quality: Optional[Literal['min', 'low', 'medium', 'high', 'max']] = 'medium'
    """
    Controls the lossy compression setting.  "max" is best quality.  "min" is smallest file size
    """
    resolution_dpi: Optional[conint(ge=9, le=600)] = 72
    """
    Dots per inch. This can range from 9 to 600.
    """
    use_transparent_background: Optional[bool] = False
    """
    If true, render the page backgrounds transparent.  Not applicable if the output is jpeg.
    """


class Model(BaseModel):
    model_config = ConfigDict(
        extra='allow',
        frozen=True,
    )
    asset_uri: AnyUrl
    """
    URI identifying the Asset.
    """
    do_ocr: Optional[bool] = False
    """
    Whether OCR processing is performed on the PDF file or not. This setting is ignored for exportpdf to image.
    """
    format: Optional[Literal['doc', 'docx', 'xls', 'xlsx', 'pptx', 'rtf', 'image']] = (
        'docx'
    )
    """
    The exportpdf format. For image file formats, the output is a zip file containing images of all the pages.
    """
    image_params: Optional[ImageParams] = None
    """
    Set of properties that are applicable when exporting to an image format.
    """
    name: constr(min_length=1)
    """
    Name of the new asset. Duplicate asset name behavior can be set by on_dup_policy.
    """
    ocr_lang: Optional[
        Literal[
            'da-DK',
            'lt-LT',
            'sl-SI',
            'el-GR',
            'ru-RU',
            'en-US',
            'zh-HK',
            'hu-HU',
            'et-EE',
            'pt-BR',
            'uk-UA',
            'nb-NO',
            'pl-PL',
            'lv-LV',
            'fi-FI',
            'ja-JP',
            'es-ES',
            'bg-BG',
            'en-GB',
            'cs-CZ',
            'mt-MT',
            'de-DE',
            'hr-HR',
            'sk-SK',
            'sr-SR',
            'ca-CA',
            'mk-MK',
            'ko-KR',
            'de-CH',
            'nl-NL',
            'zh-CN',
            'sv-SE',
            'it-IT',
            'no-NO',
            'tr-TR',
            'fr-FR',
            'ro-RO',
            'iw-IL',
        ]
    ] = 'en-US'
    """
    Locale to use for optical character recognition (when `do_ocr` is true).
    """
    on_dup_name: Optional[Literal['error', 'auto_rename', 'overwrite']] = [
        'auto_rename'
    ]
    """
    How to handle a duplicate name conflict in target collection for output file.
    """
    parent_uri: Optional[AnyUrl] = None
    """
    The uri of folder to put the asset in.  This parameter is relevant only for permanent assets.  If not specified, the default depends on the operation.  Conversions will be placed in the same folder as the source asset.
    """
    persistence: Optional[Literal['transient', 'permanent']] = 'transient'
    """
    Asset storage aspect as short-term transient vs. long-term permanent. "transient" creates an asset that will be available for several hours before being garbage collected and deleted.  For operations that convert and download immediately, "transient" is the appropriate choice
    """
